"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var esprima = require("esprima");
var escodegen = require("escodegen");
var estraverse = require("estraverse");
var unassert = require("unassert");
;
var escodegenOptions = {
    format: {
        indent: {
            style: "\t",
        },
        quotes: "auto",
    },
    comment: true
};
var UnassertPluginClass = /** @class */ (function () {
    function UnassertPluginClass(options) {
        this.test = /\.(j|t)s(x)?$/;
        this.dependencies = ["unassert"];
        this.options = options || {};
    }
    UnassertPluginClass.prototype.transform = function (file, ast) {
        // Make sure ast is done and loaded
        if (!file.analysis.ast) {
            file.loadContents();
            file.analysis.parseUsingAcorn();
            file.analysis.analyze();
        }
        /**
        
        // simple method without comments
        ast = unassert(file.analysis.ast);
        file.contents = file.context.generateCode(modifiedAST, escodegenOptions);
        return;
        
        **/
        ast = esprima.parse(file.contents, {
            range: true,
            tokens: true,
            comment: true
        });
        var attachedAst = escodegen.attachComments(ast, ast.comments, ast.tokens);
        var modifiedAst = estraverse.replace(attachedAst, unassert.createVisitor(this.options));
        file.contents = escodegen.generate(modifiedAst, escodegenOptions);
    };
    return UnassertPluginClass;
}());
exports.UnassertPluginClass = UnassertPluginClass;
exports.UnassertPlugin = function (options) {
    return new UnassertPluginClass(options || {});
};
//# sourceMappingURL=index.js.map